==> minetest-mod-skyblock_0.2.4.orig.tar.gz: minetest-skyblock-0.2.4/README.md <==
# Skyblock for Minetest

[![home](https://img.shields.io/badge/skyblock-home-blue.svg?style=flat-square)](https://cornernote.github.io/minetest-skyblock/)
[![chat](https://img.shields.io/badge/gitter-join%20chat-blue.svg?style=flat-square)](https://gitter.im/cornernote/minetest-skyblock)
[![download](https://img.shields.io/github/tag/cornernote/minetest-skyblock.svg?style=flat-square&label=release)](https://github.com/cornernote/minetest-skyblock/releases)
[![forum](https://img.shields.io/badge/minetest-mod-green.svg?style=flat-square)](https://forum.minetest.net/viewtopic.php?id=2799)
[![bower](https://img.shields.io/badge/bower-mod-green.svg?style=flat-square)](https://minetest-bower.herokuapp.com/mods/skyblock)
[![license](https://img.shields.io/badge/license-GPL3-brightgreen.svg?style=flat-square)](https://github.com/cornernote/minetest-skyblock/blob/master/LICENSE.md)


![SkyBlock](https://cloud.githubusercontent.com/assets/51875/9219481/4c7248b6-411a-11e5-81f1-5e4726a1fa99.png)


## Description

Build a world starting from a small island in the sky. This Minetest mod is intended to be used as a minimal game that allows the player to craft and use all the default items in Minetest in a fun and challenging way.


## Project Resources

* [Home](https://cornernote.github.io/minetest-skyblock/)
* [Chat](https://gitter.im/cornernote/minetest-skyblock)
* [Download](https://github.com/cornernote/minetest-skyblock/releases)
* [Forum](https://forum.minetest.net/viewtopic.php?id=2799)
* [Bower](https://minetest-bower.herokuapp.com/mods/skyblock)
* [License](https://github.com/cornernote/minetest-skyblock/blob/master/LICENSE.md)

==> minetest-mod-skyblock_0.3.0.orig.tar.gz: minetest-skyblock-0.3.0/README.md <==
# Skyblock for Minetest

[![Build status](https://github.com/cornernote/minetest-skyblock/workflows/build/badge.svg)](https://github.com/cornernote/minetest-skyblock/actions)
[![home](https://img.shields.io/badge/skyblock-home-blue.svg?style=flat-square)](https://cornernote.github.io/minetest-skyblock/)
[![chat](https://img.shields.io/badge/gitter-join%20chat-blue.svg?style=flat-square)](https://gitter.im/cornernote/minetest-skyblock)
[![download](https://img.shields.io/github/tag/cornernote/minetest-skyblock.svg?style=flat-square&label=release)](https://github.com/cornernote/minetest-skyblock/releases)
[![forum](https://img.shields.io/badge/minetest-mod-green.svg?style=flat-square)](https://forum.minetest.net/viewtopic.php?id=2799)
[![bower](https://img.shields.io/badge/bower-mod-green.svg?style=flat-square)](https://minetest-bower.herokuapp.com/mods/skyblock)
[![license](https://img.shields.io/badge/license-GPL3-brightgreen.svg?style=flat-square)](https://github.com/cornernote/minetest-skyblock/blob/master/LICENSE.md)


![SkyBlock](https://cloud.githubusercontent.com/assets/51875/9219481/4c7248b6-411a-11e5-81f1-5e4726a1fa99.png)


## Description

Build a world starting from a small island in the sky. This Minetest mod is intended to be used as a minimal game that allows the player to craft and use all the default items in Minetest in a fun and challenging way.


## Project Resources

* [Home](https://cornernote.github.io/minetest-skyblock/)
* [Chat](https://gitter.im/cornernote/minetest-skyblock)
* [Download](https://github.com/cornernote/minetest-skyblock/releases)
* [Forum](https://forum.minetest.net/viewtopic.php?id=2799)
* [Bower](https://minetest-bower.herokuapp.com/mods/skyblock)
* [License](https://github.com/cornernote/minetest-skyblock/blob/master/LICENSE.md)
